@@ -91,10 +91,22 @@ class ConsulDriver(coordination.CoordinationDriver):
     needed to make Consul being used as an option for Distributed Locking. The
     data is stored in Consul's key-value store.
 
-    To configure the client to your liking please refer
-    http://python-consul.readthedocs.org/en/latest/. Few options like 'ttl'
-    and 'namespace' will be passed as part of the options. 'ttl' governs the
-    duration till when the session holding the lock will be active.
+    The Consul driver connection URI should look like::
+
+      consul://HOST[:PORT][?OPTION1=VALUE1[&OPTION2=VALUE2[&...]]]
+
+    If not specified, PORT defaults to 8500.
+    Available options are:
+
+    ==================  =======
+    Name                Default
+    ==================  =======
+    ttl                 15
+    namespace           tooz
+    ==================  =======
+
+    For details on the available options, refer to
+    http://python-consul.readthedocs.org/en/latest/.
 
     .. _python-consul: http://python-consul.readthedocs.org/
     .. _consul: https://consul.io/
@@ -110,7 +122,7 @@ class ConsulDriver(coordination.CoordinationDriver):
     DEFAULT_PORT = 8500
 
     def __init__(self, member_id, parsed_url, options):
-        super(ConsulDriver, self).__init__(member_id)
+        super(ConsulDriver, self).__init__(member_id, parsed_url, options)
         options = utils.collapse(options)
         self._host = parsed_url.hostname
         self._port = parsed_url.port or self.DEFAULT_PORT
@@ -146,6 +158,19 @@ class ConsulDriver(coordination.CoordinationDriver):
                 self._session_id = None
             self._client = None
 
+    def heartbeat(self):
+        # THIS IS A REQUIREMENT FOR CONSUL TO WORK PROPERLY.
+        # Consul maintains a "session" token that is used to as the basis
+        # for all operations in the service. The session must be refreshed
+        # periodically or else it assumes that the agent maintaining the
+        # session has died or is unreachable. When a session expires all locks
+        # are released and any services that were registered with that session
+        # are marked as no longer active.
+        self._client.session.renew(self._session_id)
+        # renew the session every half-TTL or 1 second, whatever is larger
+        sleep_sec = max(self._ttl / 2, 1)
+        return sleep_sec
+
     def get_lock(self, name):
         real_name = self._paths_join(self._namespace, u"locks", name)
         return ConsulLock(real_name, self._node, self._address,
